Learn R Programming

sfsmisc (version 1.0-29)

ecdf.ksCI: Plot Empirical Distribution Function With 95% Confidence Curves

Description

Plots the empirical (cumulative) distribution function (ECDF) for univariate data, together with upper and lower simultaneous 95% confidence curves, computed via Kolmogorov-Smirnov' $D$, see KSd.

Usage

ecdf.ksCI(x, main = NULL, sub = NULL, xlab = deparse(substitute(x)),
          ci.col = "red", ...)

Arguments

x
x numerical vector of observations.
main,sub,xlab
arguments passed to title.
ci.col
color for confidence interval lines.
...
optional arguments passed to plot.stepfun.

Value

  • Nothing. Used for its side effect, to produce a plot.

References

Bickel and Doksum, see KSd.

See Also

ecdf and plot.stepfun in package stepfun.

Examples

Run this code
ecdf.ksCI( rchisq(50,3) )

Run the code above in your browser using DataLab