postscript or pdf, and further registering
the file name for subsequent calls to ps.end.pdf.do(file, paper = "default", onefile = FALSE,
title = NULL, version = "1.4", ...)pdf.latex(file, height = 5 + main.space * 1.25, width = 9.5,
main.space=FALSE, lab.space = main.space,
paper = "special", title = NULL,
lab=c(10, 10, 7), mgp.lab=c(1.6, 0.7, 0), mar=c(4, 4, 0.9, 1.1), ...)
ps.do(file, width=-1, height=-1, onefile=FALSE, horizontal=FALSE,
title = NULL, ...)
ps.latex(file, height = 5 + main.space * 1.25, width = 9.5,
main.space=FALSE, lab.space = main.space,
paper = "special", title = NULL,
lab=c(10, 10, 7), mgp.lab=c(1.6, 0.7, 0), mar=c(4, 4, 0.9, 1.1), ...)
height * 2.54 are
cm. The default is 5 plus 1.25 iff main.space.height, see postscript.postscript(..) or pdf(..), most probably
to be left alone.postscript() or pdf(); by default use a
title with Rversion and file in it.pdf; our (high)
default ensures alpha-transparency.mar).postscript. Only if this is
"special" are your choices of width and height
completely honored (and this may lead to files that cannot print lab[1:2] are desired number of
tick marks on x- and y- axis, see par(lab=).par(mgp=), the default is here smaller
than usual.par(mar=), the default is here smaller than usual.ps.do() or
pdf.do() from
ps.latex / pdf.latex and to ps.optionsps.latex and pdf.latex have an additional par settings from the
*.do siblings: E.g., after ps.do(..)
is called, the graphical parameters c("mar", "mgp", "lab") are
reset (to values that typically are better than the defaults for LaTeX
figures).par values}
par values}ps.end, pdf, postscript,
dev.print.ps.latex("ps.latex-ex.ps", main= TRUE) data(sunspots) plot(sunspots,main=paste("Sunspots Data, n=",length(sunspots)),col="red") ps.end()
pdf.latex("pdf.latex-ex.pdf", main= TRUE) data(sunspots) plot(sunspots,main=paste("Sunspots Data, n=",length(sunspots)),col="red") pdf.end()
ps.do("ps_do_ex.ps") example(plot.function) ps.end() }