Learn R Programming

sfsmisc (version 1.0-2)

sessionInfoX: Extended Information About the Current R Session

Description

Collect (and print) information about the current Rsession and environment, using sessionInfo() and more mostly low-level and platform dependent information.

Usage

sessionInfoX(pkgs = NULL, list.libP = FALSE, extraR.env = TRUE)

Arguments

pkgs
an optional character vector of Rpackages, whose packageDescription()s are wanted.
list.libP
a logical indicating if for all .libPaths entries, the files should be listed via list.files.
extraR.env
logical indicating if all environment variables should be recorded which start with "R_" or "_R_".

Value

  • an object of S3 class "sessionInfoX", a list with components (there may be more, experimental and not yet listed here):
  • sInfosimply the value of sessionInfo().
  • pkgDescrIf pkgs was non-empty, a named list of packageDescription()s for each entry in pkgs.
  • libPaththe value of .libPaths().
  • RLIBSa character vector of entries from Sys.getenv("R_LIBS"), typically very similar to the libPaths component.
  • n.RLIBSsimply a normalizePath()ed version of RLIBS.
  • R.enva named character vector with the important Renvironment variables R_ENVIRON, R_PROFILE, R_CHECK_ENVIRON.
  • xR.envif extraR.env was true, a named character vector of all R related environment variables, as specified in extraR.env's description above.

See Also

sessionInfo, .libPaths, R.version, Sys.getenv.

Examples

Run this code
six0 <- sessionInfoX()
sixN <- sessionInfoX("nlme", list.libP = TRUE)
sixN # -> print() method for "sessionInfoX"
names(sixN)
str(sixN, max = 1)# outline of lower-level structure
str(sixN$pkgDescr) # list with one component "nlme"

Run the code above in your browser using DataLab